@@ -1,18 +1,19 @@
 import os
 
-from keras.models import *
-from keras.layers import *
+from tensorflow.keras.models import *
+from tensorflow.keras.layers import *
 
 from .config import IMAGE_ORDERING
 from .model_utils import get_segmentation_model
 from axelerate.networks.common_utils.feature import create_feature_extractor
 
-mobilenet = {1:10,2:23,3:36,4:73,5:86 }
-vgg16 = {1:3,2:6,3:10,4:14,5:18 }
-squeezenet = {1:2,2:17,3:32,4:47,5:61 }
-full_yolo = {1:14,2:27,3:40,4:53,5:73 }
-tiny_yolo = {1:7,2:15,3:23,4:27,5:30 }
-resnet50 = {1:2,2:37,3:80,4:142,5:174 }
+mobilenet = {1:10,2:23,3:36,4:73,5:86}
+densenet121 = {1:8,2:50,3:138,4:310,5:426}
+nasnetmobile = {1:7,2:64,3:295,4:537,5:768}
+squeezenet = {1:2,2:17,3:32,4:47,5:61}
+full_yolo = {1:14,2:27,3:40,4:53,5:73}
+tiny_yolo = {1:7,2:15,3:23,4:27,5:30}
+resnet50 = {1:2,2:37,3:80,4:142,5:174}
 
 def chopper(model, model_name, f):
     outputs = model.layers[model_name[f]].output
@@ -49,33 +50,35 @@ def segnet_decoder(f, n_classes, n_up=3):
     return o
 
 
-def _segnet(n_classes, encoder_input, encoder_output,  input_height=416, input_width=608,
-            encoder_level=3):
+def _segnet(n_classes, encoder_input, encoder_output,  input_height=416, input_width=608, encoder_level=3):
 
-    o = segnet_decoder(encoder_output, n_classes, n_up=3)
+    o = segnet_decoder(f=encoder_output, n_classes=n_classes, n_up=encoder_level-1)
     model = get_segmentation_model(encoder_input, o)
 
     return model
 
-
 def full_yolo_segnet(n_classes, input_size, encoder_level, weights):
 
     encoder = create_feature_extractor('Full Yolo',input_size, weights)
     encoder_output = encoder.feature_extractor.layers[full_yolo[encoder_level]].output
+    print(encoder_output)
     encoder_input = encoder.feature_extractor.inputs[0]
-
+    encoder_level += 1
     model = _segnet(n_classes, encoder_input, encoder_output, input_size, encoder_level=encoder_level)
-    model.model_name = "vgg_segnet"
+    model.model_name = "full_yolo_segnet"
+    model.normalize = encoder.normalize
     return model
 
 def tiny_yolo_segnet(n_classes, input_size, encoder_level, weights):
 
     encoder = create_feature_extractor('Tiny Yolo',input_size, weights)
     encoder_output = encoder.feature_extractor.layers[tiny_yolo[encoder_level]].output
+    print(encoder_output)
     encoder_input = encoder.feature_extractor.inputs[0]
-
+    encoder_level += 1
     model = _segnet(n_classes, encoder_input, encoder_output, input_size, encoder_level=encoder_level)
-    model.model_name = "vgg_segnet"
+    model.model_name = "tiny_yolo_segnet"
+    model.normalize = encoder.normalize
     return model
 
 def squeezenet_segnet(n_classes, input_size, encoder_level, weights):
@@ -85,19 +88,31 @@ def squeezenet_segnet(n_classes, input_size, encoder_level, weights):
     encoder_input = encoder.feature_extractor.inputs[0]
 
     model = _segnet(n_classes, encoder_input, encoder_output, input_size, encoder_level=encoder_level)
-    model.model_name = "vgg_segnet"
+    model.model_name = "squeezenet_segnet"
+    model.normalize = encoder.normalize
     return model
 
-def vgg16_segnet(n_classes, input_size, encoder_level, weights):
+def densenet121_segnet(n_classes, input_size, encoder_level, weights):
 
-    encoder = create_feature_extractor('VGG16',input_size, weights)
-    encoder_output = encoder.feature_extractor.layers[vgg16[encoder_level]].output
+    encoder = create_feature_extractor('DenseNet121', input_size, weights)
+    encoder_output = encoder.feature_extractor.layers[densenet121[encoder_level]].output
     encoder_input = encoder.feature_extractor.inputs[0]
 
     model = _segnet(n_classes, encoder_input, encoder_output, input_size, encoder_level=encoder_level)
-    model.model_name = "vgg_segnet"
+    model.model_name = "densenet121_segnet"
+    model.normalize = encoder.normalize
     return model
 
+def nasnetmobile_segnet(n_classes, input_size, encoder_level, weights):
+
+    encoder = create_feature_extractor('NASNetMobile', input_size, weights)
+    encoder_output = encoder.feature_extractor.layers[nasnetmobile[encoder_level]].output
+    encoder_input = encoder.feature_extractor.inputs[0]
+
+    model = _segnet(n_classes, encoder_input, encoder_output, input_size, encoder_level=encoder_level)
+    model.model_name = "nasnetmobile_segnet"
+    model.normalize = encoder.normalize
+    return model
 
 def resnet50_segnet(n_classes, input_size, encoder_level, weights):
 
@@ -107,6 +122,7 @@ def resnet50_segnet(n_classes, input_size, encoder_level, weights):
 
     model = _segnet(n_classes, encoder_input, encoder_output, input_size, encoder_level=encoder_level)
     model.model_name = "resnet50_segnet"
+    model.normalize = encoder.normalize
     return model
 
 
@@ -115,8 +131,9 @@ def mobilenet_segnet(n_classes, input_size, encoder_level, weights, architecture
     encoder = create_feature_extractor(architecture, input_size, weights)
     encoder_output = encoder.feature_extractor.layers[mobilenet[encoder_level]].output
     encoder_input = encoder.feature_extractor.inputs[0]
-
+    
     model = _segnet(n_classes, encoder_input, encoder_output, input_size, encoder_level=encoder_level)
     model.model_name = "mobilenet_segnet"
+    model.normalize = encoder.normalize
     return model
 
