@@ -7,27 +7,16 @@ import cv2
 import numpy as np
 np.set_printoptions(threshold=np.inf)
 from tqdm import tqdm
-from keras.models import load_model
+from tensorflow.keras.models import load_model
 
 from axelerate.networks.segnet.train import find_latest_checkpoint
 from axelerate.networks.segnet.data_utils.data_loader import get_image_array, get_segmentation_array, DATA_LOADER_SEED, class_colors, get_pairs_from_paths
 from axelerate.networks.segnet.models.config import IMAGE_ORDERING
 from . import metrics
-import matplotlib.pyplot as plt
 import six
 
-
 random.seed(DATA_LOADER_SEED)
 
-def show_image(image):
-    #image = mpimg.imread(filename)
-    plt.figure()
-    plt.imshow(image)
-    plt.show(block=False)
-    plt.pause(1)
-    plt.close()
-    #print(filename)
-
 def model_from_checkpoint_path(checkpoints_path):
 
     from .models.all_models import model_from_name
@@ -44,23 +33,17 @@ def model_from_checkpoint_path(checkpoints_path):
     model.load_weights(latest_weights)
     return model
 
-
-
 def get_colored_segmentation_image(seg_arr, n_classes, colors=class_colors):
     output_height = seg_arr.shape[0]
     output_width = seg_arr.shape[1]
-
     seg_img = np.zeros((output_height, output_width, 3))
-
     for c in range(n_classes):
         seg_img[:, :, 0] += ((seg_arr[:, :] == c)*(colors[c][0])).astype('uint8')
         seg_img[:, :, 1] += ((seg_arr[:, :] == c)*(colors[c][1])).astype('uint8')
         seg_img[:, :, 2] += ((seg_arr[:, :] == c)*(colors[c][2])).astype('uint8')
-
+    seg_img = seg_img.astype('uint8')
     return seg_img 
 
-
-
 def get_legends(class_names,  colors=class_colors): 
     
     n_classes = len(class_names)
@@ -76,7 +59,7 @@ def get_legends(class_names,  colors=class_colors):
         
     return legend    
 
-def overlay_seg_image( inp_img , seg_img  ):
+def overlay_seg_image(inp_img , seg_img):
     orininal_h = inp_img.shape[0]
     orininal_w = inp_img.shape[1]
     seg_img = cv2.resize(seg_img, (orininal_w, orininal_h))
@@ -96,9 +79,8 @@ def concat_lenends(  seg_img , legend_img  ):
 
     return out_img
 
-
-def visualize_segmentation(seg_arr, inp_img=None, n_classes=None , 
-    colors=class_colors, class_names=None,overlay_img=False, show_legends=False , 
+def visualize_segmentation(seg_arr, inp_img=None, n_classes=None, 
+    colors=class_colors, class_names=None, overlay_img=False, show_legends=False, 
     prediction_width=None, prediction_height=None):
     
     print("Found the following classes in the segmentation image:", np.unique(seg_arr))
@@ -106,68 +88,45 @@ def visualize_segmentation(seg_arr, inp_img=None, n_classes=None ,
     if n_classes is None:
         n_classes = np.max(seg_arr)
 
-    seg_img = get_colored_segmentation_image(seg_arr, n_classes , colors=colors )
+    seg_img = get_colored_segmentation_image(seg_arr, n_classes , colors=colors)
 
     if not inp_img is None:
         orininal_h = inp_img.shape[0]
         orininal_w = inp_img.shape[1]
         seg_img = cv2.resize(seg_img, (orininal_w, orininal_h))
 
-
-    if (not prediction_height is None) and  (not prediction_width is None):
+    if (not prediction_height is None) and (not prediction_width is None):
         seg_img = cv2.resize(seg_img, (prediction_width, prediction_height ))
         if not inp_img is None:
-            inp_img = cv2.resize(inp_img, (prediction_width, prediction_height ))
-
-
+            inp_img = cv2.resize(inp_img, (prediction_width, prediction_height))
+            
     if overlay_img:
         assert not inp_img is None
-        seg_img = overlay_seg_image(inp_img , seg_img)
-
+        seg_img = overlay_seg_image(inp_img, seg_img)
 
     if show_legends:
         assert not class_names is None
         legend_img = get_legends(class_names , colors=colors )
 
-        seg_img = concat_lenends( seg_img , legend_img )
+        seg_img = concat_lenends(seg_img, legend_img)
 
     return seg_img
 
-
-
-
-def predict(model=None, inp=None, out_fname=None, checkpoints_path=None, overlay_img=False,
+def predict(model=None, inp=None, out_fname=None, image = None, overlay_img=False,
     class_names=None, show_legends=False, colors=class_colors, prediction_width=None, prediction_height=None):
 
-    if model is None and (checkpoints_path is not None):
-        model = model_from_checkpoint_path(checkpoints_path)
-
-    assert (inp is not None)
-    assert((type(inp) is np.ndarray) or isinstance(inp, six.string_types)
-           ), "Input should be the CV image or the input file name"
-
-    if isinstance(inp, six.string_types):
-        inp = cv2.imread(inp)
-
-    assert len(inp.shape) == 3, "Image should be h,w,3 "
-    orininal_h = inp.shape[0]
-    orininal_w = inp.shape[1]
-
-    output_width = model.output_width
-    output_height = model.output_height
-    input_width = model.input_width
-    input_height = model.input_height
     n_classes = model.n_classes
 
-    x = get_image_array(inp, input_width, input_height, ordering=IMAGE_ORDERING)
-    pr = model.predict(np.array([x]))[0]
+    pr = model.predict(inp)
+    pr = np.squeeze(pr)
+
     #pr = pr.reshape((output_height,  output_width, n_classes)).argmax(axis=2)
     pr = pr.argmax(axis=2)
-    seg_img = visualize_segmentation(pr, inp, n_classes=n_classes, colors=colors, overlay_img=overlay_img, show_legends=show_legends, class_names=class_names, prediction_width=prediction_width, prediction_height=prediction_height)
+
+    seg_img = visualize_segmentation(pr, inp_img=image, n_classes=n_classes, overlay_img=True, colors=colors)
 
     if out_fname is not None:
         cv2.imwrite(out_fname, seg_img)
-        show_image(seg_img)
 
     return pr
 
@@ -249,5 +208,3 @@ def evaluate( model=None , inp_images=None , annotations=None,inp_images_dir=Non
     frequency_weighted_IU = np.sum(cl_wise_score*n_pixels_norm)
     mean_IU = np.mean(cl_wise_score)
     return {"frequency_weighted_IU":frequency_weighted_IU , "mean_IU":mean_IU , "class_wise_IU":cl_wise_score }
-
-
