@@ -7,7 +7,6 @@ import time
 import numpy as np
 
 from axelerate.networks.common_utils.fit import train
-
 from axelerate.networks.yolo.backend.decoder import YoloDecoder
 from axelerate.networks.yolo.backend.loss import YoloLoss
 from axelerate.networks.yolo.backend.network import create_yolo_network
@@ -66,10 +65,10 @@ class YOLO(object):
         self._input_size = input_size
         self._norm = yolo_network._norm
 
-    def load_weights(self, weight_path, by_name=False):
+    def load_weights(self, weight_path, by_name=True):
         if os.path.exists(weight_path):
             print("Loading pre-trained weights for the whole model: ", weight_path)
-            self._yolo_network.load_weights(weight_path, by_name=by_name)
+            self._yolo_network.load_weights(weight_path, by_name=True)
         else:
             print("Failed to load pre-trained weights for the whole model. It might be because you didn't specify any or the weight file cannot be found")
 
@@ -125,6 +124,10 @@ class YOLO(object):
                                                                      valid_ann_folder,
                                                                      is_only_detect=False)
         # 1. get batch generator
+        valid_batch_size = len(valid_annotations)*valid_times
+        if valid_batch_size < batch_size: 
+            raise ValueError("Not enough validation images: batch size {} is larger than {} validation images. Add more validation images or decrease batch size!".format(batch_size, valid_batch_size))
+        
         train_batch_generator = self._get_batch_generator(train_annotations, batch_size, train_times, jitter=jitter)
         valid_batch_generator = self._get_batch_generator(valid_annotations, batch_size, valid_times, jitter=False)
         
