@@ -1,11 +1,13 @@
-# -*- coding: utf-8 -*-
-
+import shutil
 import numpy as np
 np.random.seed(111)
 import argparse
 import os
+import time
 import sys
 import json
+import matplotlib
+
 from axelerate.networks.yolo.frontend import create_yolo, get_object_labels
 from axelerate.networks.classifier.frontend_classifier import create_classifier, get_labels
 from axelerate.networks.segnet.frontend_segnet import create_segnet
@@ -16,21 +18,21 @@ import tensorflow as tf
 
 tf.get_logger().setLevel('ERROR')
 
-gpu_options = tf.GPUOptions(per_process_gpu_memory_fraction=0.5)
-config = tf.ConfigProto(gpu_options=gpu_options)
-config.gpu_options.allow_growth = True
-session = tf.Session(config=config)
-
 argparser = argparse.ArgumentParser(
     description='Train and validate YOLO_v2 model on any dataset')
 
 argparser.add_argument(
     '-c',
-    '--conf',
+    '--config',
     default="configs/from_scratch.json",
     help='path to configuration file')
 
 def train_from_config(config,project_folder):
+    try:
+        matplotlib.use('Agg')
+    except:
+        pass
+
     #added for compatibility with < 0.5.7 versions
     try:
         input_size = config['model']['input_size'][:]
@@ -38,8 +40,7 @@ def train_from_config(config,project_folder):
         input_size = [config['model']['input_size'],config['model']['input_size']]
 
     # Create the converter
-    converter = Converter(config['converter']['type'], config['model']['architecture'],
-                          input_size, config['train']['valid_image_folder'])
+    converter = Converter(config['converter']['type'], config['model']['architecture'], config['train']['valid_image_folder'])
 
     #  Segmentation network
     if config['model']['type']=='SegNet':
@@ -140,10 +141,11 @@ def train_from_config(config,project_folder):
                                            config['train']['first_trainable_layer'],
                                            config['train']['valid_metric'])
     # 4 Convert the model
-    converter.convert_model(model_path,model_layers,config['train']['valid_image_folder'])    
+    time.sleep(2)
+    converter.convert_model(model_path)    
     return model_path
 
-def setup_training(config_file=None,config_dict=None):
+def setup_training(config_file=None, config_dict=None):
     """make directory to save weights & its configuration """
     if config_file:
         with open(config_file) as config_buffer:
@@ -159,10 +161,21 @@ def setup_training(config_file=None,config_dict=None):
     else:
         print("Project folder {} is created.".format(dirname, dirname))
         os.makedirs(dirname)
-    #print("Weight file and Config file will be saved in \"{}\"".format(dirname))
+
     return(train_from_config(config, dirname))
 
 
 if __name__ == '__main__':
+
+    argparser = argparse.ArgumentParser(
+        description='Train and validate YOLO_v2 model on any dataset')
+
+    argparser.add_argument(
+        '-c',
+        '--config',
+        default="configs/classifer.json",
+        help='path to configuration file')
+
     args = argparser.parse_args()
-    setup_training(args.conf)
+    setup_training(config_file=args.config)
+    shutil.rmtree("logs", ignore_errors=True)
